# ValidationOutcome

Generic class to indicate if a validation passed or failed.

## Enum

* `PASS` (value: `'pass'`)

* `FAIL` (value: `'fail'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


